Enum input_sys::libinput_device_capability
[−]
[src]
#[repr(u32)]pub enum libinput_device_capability { LIBINPUT_DEVICE_CAP_KEYBOARD, LIBINPUT_DEVICE_CAP_POINTER, LIBINPUT_DEVICE_CAP_TOUCH, LIBINPUT_DEVICE_CAP_TABLET_TOOL, LIBINPUT_DEVICE_CAP_TABLET_PAD, LIBINPUT_DEVICE_CAP_GESTURE, LIBINPUT_DEVICE_CAP_SWITCH, }
@ingroup device
Capabilities on a device. A device may have one or more capabilities at a time, capabilities remain static for the lifetime of the device.
Variants
LIBINPUT_DEVICE_CAP_KEYBOARDLIBINPUT_DEVICE_CAP_POINTERLIBINPUT_DEVICE_CAP_TOUCHLIBINPUT_DEVICE_CAP_TABLET_TOOLLIBINPUT_DEVICE_CAP_TABLET_PADLIBINPUT_DEVICE_CAP_GESTURELIBINPUT_DEVICE_CAP_SWITCHTrait Implementations
impl Debug for libinput_device_capability[src]
impl Copy for libinput_device_capability[src]
impl Clone for libinput_device_capability[src]
fn clone(&self) -> libinput_device_capability
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for libinput_device_capability[src]
fn eq(&self, __arg_0: &libinput_device_capability) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.