Enum input_sys::libinput_switch_state
[−]
[src]
#[repr(u32)]pub enum libinput_switch_state { LIBINPUT_SWITCH_STATE_OFF, LIBINPUT_SWITCH_STATE_ON, }
@ingroup device
The state of a switch. The default state of a switch is @ref LIBINPUT_SWITCH_STATE_OFF and no event is sent to confirm a switch in the off position. If a switch is logically on during initialization, libinput sends an event of type @ref LIBINPUT_EVENT_SWITCH_TOGGLE with a state @ref LIBINPUT_SWITCH_STATE_ON.
Variants
LIBINPUT_SWITCH_STATE_OFFLIBINPUT_SWITCH_STATE_ONTrait Implementations
impl Debug for libinput_switch_state[src]
impl Copy for libinput_switch_state[src]
impl Clone for libinput_switch_state[src]
fn clone(&self) -> libinput_switch_state
Returns a copy of the value. Read more
fn clone_from(&mut self, source: &Self)1.0.0
Performs copy-assignment from source. Read more
impl PartialEq for libinput_switch_state[src]
fn eq(&self, __arg_0: &libinput_switch_state) -> bool
This method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &Rhs) -> bool1.0.0
This method tests for !=.