Function input_sys::libinput_event_tablet_tool_get_seat_button_count [] [src]

pub unsafe extern "C" fn libinput_event_tablet_tool_get_seat_button_count(
    event: *mut libinput_event_tablet_tool
) -> u32
  • @ingroup event_tablet *
  • For the button of a @ref LIBINPUT_EVENT_TABLET_TOOL_BUTTON event, return the total
  • number of buttons pressed on all devices on the associated seat after the
  • the event was triggered. * " @note It is an application bug to call this function for events other than
  • @ref LIBINPUT_EVENT_TABLET_TOOL_BUTTON. For other events, this function returns 0. *
  • @param event The libinput tablet tool event
  • @return the seat wide pressed button count for the key of this event