Function input_sys::libinput_event_tablet_tool_get_tool [] [src]

pub unsafe extern "C" fn libinput_event_tablet_tool_get_tool(
    event: *mut libinput_event_tablet_tool
) -> *mut libinput_tablet_tool
  • @ingroup event_tablet *
  • Returns the tool that was in use during this event. *
  • The returned tablet tool is not refcounted and may become invalid after
  • the next call to libinput. Use libinput_tablet_tool_ref() and
  • libinput_tablet_tool_unref() to continue using the handle outside of the
  • immediate scope. *
  • If the caller holds at least one reference, this struct is used
  • whenever the tools enters proximity again. *
  • @note Physical tool tracking requires hardware support. If unavailable,
  • libinput creates one tool per type per tablet. See @ref
  • tablet-serial-numbers for more details. *
  • @param event The libinput tablet tool event
  • @return The new tool triggering this event